@@ -9,7 +9,7 @@ import time
 
 class TkpStruct(object):
 
-    def __init__(self, curl_prod=None, curl_stag=None, file_id=None):
+    def __init__(self, curl_prod=None, curl_stag=None, file_id=None, additional_info=None):
         self.request_presenter = None
         if not curl_stag is None :
             self.request_stag = LurlRequest(curl_stag)
@@ -23,6 +23,7 @@ class TkpStruct(object):
             self.request_prod = dict()
         self.base = None
         self.file_id = file_id
+        self.additional_info = additional_info
 
     def get_as_tkp(self):
         self.construct()
@@ -36,7 +37,7 @@ class TkpStruct(object):
             path_for_file = path_for_file + sub_path.capitalize()
         if not self.file_id is None:
             path_for_file = path_for_file + "_" + self.file_id
-        file_name = "test_SERVICENAME_"+path_for_file+".json"
+        file_name = "test_"+ self.get_service_name() + "_" + path_for_file + ".json"
         f = open(file_name, "w")
         f.write(json.dumps(self.base, indent=4, sort_keys=True))
         f.close()
@@ -50,10 +51,10 @@ class TkpStruct(object):
     def construct_base(self) :
         self.base = {
             "queryName": self.get_queryName(),
-            "serviceName":"REPLACE_TO_SERVICE_NAME",
+            "serviceName": self.get_service_name(),
             "apiName": self.get_apiName(),
-            "testCaseDescription": "call " + self.request_presenter.path,
-            "testCasePriority": "P1",
+            "testCaseDescription": self.get_description(),
+            "testCasePriority": self.get_priority(),
             "httpMethod":self.request_presenter.method,
             "headerMap":self.request_presenter.headers,
             "query":"",
@@ -90,6 +91,24 @@ class TkpStruct(object):
         env_name = "staging"
         return self.set_structure(env_name, self.request_stag)
     
+    def get_description(self):
+        if 'description' in self.additional_info :
+            return self.additional_info['description']
+        else :
+            return "call " + self.request_presenter.path
+
+    def get_priority(self):
+        if 'priority' in self.additional_info :
+            return self.additional_info['priority']
+        else :
+            return "P1"
+    
+    def get_service_name(self):
+        if 'service' in self.additional_info :
+            return self.additional_info['service']
+        else :
+            return "SERVICENAME"
+    
     def set_structure(self, env_name, request) :
         if not bool(request) :
             structure = {
